from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel:ARLevel[:STATe] \n
		Snippet: driver.applications.k17Mcgd.configure.generator.mcgd.level.arLevel.state.set(state = False) \n
		Determines the behavior of the reference level. \n
			:param state: ON | OFF | 0 | 1 ON | 1 The R&S FSW automatically adapts the reference level if 'Level (RMS) ' or the 'DUT Gain' is changed. OFF | 0 The reference level is not automatically adapted.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:GENerator:MCGD:LEVel:ARLevel:STATe {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel:ARLevel[:STATe] \n
		Snippet: value: bool = driver.applications.k17Mcgd.configure.generator.mcgd.level.arLevel.state.get() \n
		Determines the behavior of the reference level. \n
			:return: state: ON | OFF | 0 | 1 ON | 1 The R&S FSW automatically adapts the reference level if 'Level (RMS) ' or the 'DUT Gain' is changed. OFF | 0 The reference level is not automatically adapted."""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:LEVel:ARLevel:STATe?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EvmCls:
	"""Evm commands group definition. 35 total commands, 27 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("evm", core, parent)

	@property
	def all(self):
		"""all commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def dsqp(self):
		"""dsqp commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dsqp'):
			from .Dsqp import DsqpCls
			self._dsqp = DsqpCls(self._core, self._cmd_group)
		return self._dsqp

	@property
	def dssf(self):
		"""dssf commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dssf'):
			from .Dssf import DssfCls
			self._dssf = DssfCls(self._core, self._cmd_group)
		return self._dssf

	@property
	def dsst(self):
		"""dsst commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dsst'):
			from .Dsst import DsstCls
			self._dsst = DsstCls(self._core, self._cmd_group)
		return self._dsst

	@property
	def dsts(self):
		"""dsts commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dsts'):
			from .Dsts import DstsCls
			self._dsts = DstsCls(self._core, self._cmd_group)
		return self._dsts

	@property
	def ds1K(self):
		"""ds1K commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ds1K'):
			from .Ds1K import Ds1KCls
			self._ds1K = Ds1KCls(self._core, self._cmd_group)
		return self._ds1K

	@property
	def pchannel(self):
		"""pchannel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pchannel'):
			from .Pchannel import PchannelCls
			self._pchannel = PchannelCls(self._core, self._cmd_group)
		return self._pchannel

	@property
	def psignal(self):
		"""psignal commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_psignal'):
			from .Psignal import PsignalCls
			self._psignal = PsignalCls(self._core, self._cmd_group)
		return self._psignal

	@property
	def sdop(self):
		"""sdop commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sdop'):
			from .Sdop import SdopCls
			self._sdop = SdopCls(self._core, self._cmd_group)
		return self._sdop

	@property
	def sdqp(self):
		"""sdqp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sdqp'):
			from .Sdqp import SdqpCls
			self._sdqp = SdqpCls(self._core, self._cmd_group)
		return self._sdqp

	@property
	def sdsf(self):
		"""sdsf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sdsf'):
			from .Sdsf import SdsfCls
			self._sdsf = SdsfCls(self._core, self._cmd_group)
		return self._sdsf

	@property
	def sdst(self):
		"""sdst commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sdst'):
			from .Sdst import SdstCls
			self._sdst = SdstCls(self._core, self._cmd_group)
		return self._sdst

	@property
	def sdts(self):
		"""sdts commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sdts'):
			from .Sdts import SdtsCls
			self._sdts = SdtsCls(self._core, self._cmd_group)
		return self._sdts

	@property
	def spop(self):
		"""spop commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_spop'):
			from .Spop import SpopCls
			self._spop = SpopCls(self._core, self._cmd_group)
		return self._spop

	@property
	def spqp(self):
		"""spqp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_spqp'):
			from .Spqp import SpqpCls
			self._spqp = SpqpCls(self._core, self._cmd_group)
		return self._spqp

	@property
	def spst(self):
		"""spst commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_spst'):
			from .Spst import SpstCls
			self._spst = SpstCls(self._core, self._cmd_group)
		return self._spst

	@property
	def uccd(self):
		"""uccd commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_uccd'):
			from .Uccd import UccdCls
			self._uccd = UccdCls(self._core, self._cmd_group)
		return self._uccd

	@property
	def ucch(self):
		"""ucch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ucch'):
			from .Ucch import UcchCls
			self._ucch = UcchCls(self._core, self._cmd_group)
		return self._ucch

	@property
	def upop(self):
		"""upop commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_upop'):
			from .Upop import UpopCls
			self._upop = UpopCls(self._core, self._cmd_group)
		return self._upop

	@property
	def upqp(self):
		"""upqp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_upqp'):
			from .Upqp import UpqpCls
			self._upqp = UpqpCls(self._core, self._cmd_group)
		return self._upqp

	@property
	def upra(self):
		"""upra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_upra'):
			from .Upra import UpraCls
			self._upra = UpraCls(self._core, self._cmd_group)
		return self._upra

	@property
	def upst(self):
		"""upst commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_upst'):
			from .Upst import UpstCls
			self._upst = UpstCls(self._core, self._cmd_group)
		return self._upst

	@property
	def usop(self):
		"""usop commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_usop'):
			from .Usop import UsopCls
			self._usop = UsopCls(self._core, self._cmd_group)
		return self._usop

	@property
	def usqp(self):
		"""usqp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_usqp'):
			from .Usqp import UsqpCls
			self._usqp = UsqpCls(self._core, self._cmd_group)
		return self._usqp

	@property
	def ussf(self):
		"""ussf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ussf'):
			from .Ussf import UssfCls
			self._ussf = UssfCls(self._core, self._cmd_group)
		return self._ussf

	@property
	def usst(self):
		"""usst commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_usst'):
			from .Usst import UsstCls
			self._usst = UsstCls(self._core, self._cmd_group)
		return self._usst

	@property
	def usts(self):
		"""usts commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_usts'):
			from .Usts import UstsCls
			self._usts = UstsCls(self._core, self._cmd_group)
		return self._usts

	def clone(self) -> 'EvmCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EvmCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UssfCls:
	"""Ussf commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ussf", core, parent)

	def get(self) -> float:
		"""SCPI: FETCh:ALL:SUMMary:EVM:USSF \n
		Snippet: value: float = driver.applications.k14Xnr5G.fetch.all.summary.evm.ussf.get() \n
		This command queries the EVM of all PUSCH resource elements with a 64QAM modulation.
			INTRO_CMD_HELP: method RsFsw.Applications.K14x_Nr5G.Fetch.All.Summary.Evm.Ussf.get_ queries the average result over all carriers. Prerequisites: \n
			- Select to evaluate all carriers ([SENSe:]NR5G:RSUMmary:CCResult) . \n
			:return: evm: EVM in % or dB."""
		response = self._core.io.query_str(f'FETCh:ALL:SUMMary:EVM:USSF?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FunctionCls:
	"""Function commands group definition. 23 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("function", core, parent)

	@property
	def power(self):
		"""power commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def center(self):
		"""center commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def fpeaks(self):
		"""fpeaks commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_fpeaks'):
			from .Fpeaks import FpeaksCls
			self._fpeaks = FpeaksCls(self._core, self._cmd_group)
		return self._fpeaks

	@property
	def noise(self):
		"""noise commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_noise'):
			from .Noise import NoiseCls
			self._noise = NoiseCls(self._core, self._cmd_group)
		return self._noise

	@property
	def reference(self):
		"""reference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	def clone(self) -> 'FunctionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FunctionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZoomCls:
	"""Zoom commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("zoom", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:SPAN:ZOOM \n
		Snippet: driver.applications.k17Mcgd.sense.ademod.spectrum.span.zoom.set(value = 1.0) \n
		This command sets the span. Note that this command is maintained for compatibility reasons only.
		Use [SENSe:]FREQuency:SPAN for new remote control programs. \n
			:param value: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'SENSe:ADEMod:SPECtrum:SPAN:ZOOM {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:SPAN:ZOOM \n
		Snippet: value: float = driver.applications.k17Mcgd.sense.ademod.spectrum.span.zoom.get() \n
		This command sets the span. Note that this command is maintained for compatibility reasons only.
		Use [SENSe:]FREQuency:SPAN for new remote control programs. \n
			:return: value: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:ADEMod:SPECtrum:SPAN:ZOOM?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RbCountCls:
	"""RbCount commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rbCount", core, parent)

	def set(self, resource_blocks: float, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default, cluster=repcap.Cluster.Default) -> None:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:SUBFrame<sf>:ALLoc[:CLUSter<cl>]:RBCount \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.cc.subframe.alloc.cluster.rbCount.set(resource_blocks = 1.0, carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default, cluster = repcap.Cluster.Default) \n
		This command selects the number of resource blocks in an uplink subframe. \n
			:param resource_blocks: numeric value
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:param cluster: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cluster')
		"""
		param = Conversions.decimal_value_to_str(resource_blocks)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		cluster_cmd_val = self._cmd_group.get_repcap_cmd_value(cluster, repcap.Cluster)
		self._core.io.write(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc:CLUSter{cluster_cmd_val}:RBCount {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default, cluster=repcap.Cluster.Default) -> float:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:SUBFrame<sf>:ALLoc[:CLUSter<cl>]:RBCount \n
		Snippet: value: float = driver.applications.k10Xlte.configure.lte.uplink.cc.subframe.alloc.cluster.rbCount.get(carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default, cluster = repcap.Cluster.Default) \n
		This command selects the number of resource blocks in an uplink subframe. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:param cluster: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cluster')
			:return: resource_blocks: numeric value"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		cluster_cmd_val = self._cmd_group.get_repcap_cmd_value(cluster, repcap.Cluster)
		response = self._core.io.query_str(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc:CLUSter{cluster_cmd_val}:RBCount?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RiqCls:
	"""Riq commands group definition. 14 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("riq", core, parent)

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def fiq(self):
		"""fiq commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_fiq'):
			from .Fiq import FiqCls
			self._fiq = FiqCls(self._core, self._cmd_group)
		return self._fiq

	@property
	def pfm(self):
		"""pfm commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pfm'):
			from .Pfm import PfmCls
			self._pfm = PfmCls(self._core, self._cmd_group)
		return self._pfm

	@property
	def barker(self):
		"""barker commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_barker'):
			from .Barker import BarkerCls
			self._barker = BarkerCls(self._core, self._cmd_group)
		return self._barker

	@property
	def ebarker(self):
		"""ebarker commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ebarker'):
			from .Ebarker import EbarkerCls
			self._ebarker = EbarkerCls(self._core, self._cmd_group)
		return self._ebarker

	def clone(self) -> 'RiqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RiqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, count: int) -> None:
		"""SCPI: [SENSe]:BURSt:SELect \n
		Snippet: driver.applications.k9X11Ad.sense.burst.select.set(count = 1) \n
		If single PPDU analysis is enabled (see [SENSe:]BURSt:SELect:STATe) , the IEEE 802.11ad I/Q results are based on the
		specified PPDU. If disabled, all detected PPDUs in the current capture buffer are evaluated. \n
			:param count: No help available
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SENSe:BURSt:SELect {param}')

	def get(self) -> int:
		"""SCPI: [SENSe]:BURSt:SELect \n
		Snippet: value: int = driver.applications.k9X11Ad.sense.burst.select.get() \n
		If single PPDU analysis is enabled (see [SENSe:]BURSt:SELect:STATe) , the IEEE 802.11ad I/Q results are based on the
		specified PPDU. If disabled, all detected PPDUs in the current capture buffer are evaluated. \n
			:return: count: No help available"""
		response = self._core.io.query_str(f'SENSe:BURSt:SELect?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'SelectCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SelectCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TrackingCls:
	"""Tracking commands group definition. 7 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tracking", core, parent)

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import PhaseCls
			self._phase = PhaseCls(self._core, self._cmd_group)
		return self._phase

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import TimeCls
			self._time = TimeCls(self._core, self._cmd_group)
		return self._time

	@property
	def pilots(self):
		"""pilots commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pilots'):
			from .Pilots import PilotsCls
			self._pilots = PilotsCls(self._core, self._cmd_group)
		return self._pilots

	@property
	def preamble(self):
		"""preamble commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_preamble'):
			from .Preamble import PreambleCls
			self._preamble = PreambleCls(self._core, self._cmd_group)
		return self._preamble

	@property
	def iqMcomp(self):
		"""iqMcomp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqMcomp'):
			from .IqMcomp import IqMcompCls
			self._iqMcomp = IqMcompCls(self._core, self._cmd_group)
		return self._iqMcomp

	@property
	def crosstalk(self):
		"""crosstalk commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crosstalk'):
			from .Crosstalk import CrosstalkCls
			self._crosstalk = CrosstalkCls(self._core, self._cmd_group)
		return self._crosstalk

	def clone(self) -> 'TrackingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TrackingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TDOMain:X[:SCALe]:MODE \n
		Snippet: driver.applications.k18AmplifierEt.display.window.tdomain.x.scale.mode.set(state = False, window = repcap.Window.Default) \n
		This command turns automatic scaling of the x-axis in the time domain result display on and off. \n
			:param state: ON | 1 Turns on automatic scaling of the x-axis. OFF | 0 Turns on manual scaling of the x-axis.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TDOMain:X:SCALe:MODE {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>]:TDOMain:X[:SCALe]:MODE \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.display.window.tdomain.x.scale.mode.get(window = repcap.Window.Default) \n
		This command turns automatic scaling of the x-axis in the time domain result display on and off. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: state: ON | 1 Turns on automatic scaling of the x-axis. OFF | 0 Turns on manual scaling of the x-axis."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TDOMain:X:SCALe:MODE?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, carriers: int) -> None:
		"""SCPI: CONFigure:BURSt:CONSt:CARRier:SELect \n
		Snippet: driver.applications.k91Wlan.configure.burst.const.carrier.select.set(carriers = 1) \n
		Defines the carriers included in the constellation diagram. \n
			:param carriers: ALL Results for all carriers PILots Results for pilot carriers only integer Specific carrier number only
		"""
		param = Conversions.decimal_value_to_str(carriers)
		self._core.io.write(f'CONFigure:BURSt:CONSt:CARRier:SELect {param}')

	def get(self) -> int:
		"""SCPI: CONFigure:BURSt:CONSt:CARRier:SELect \n
		Snippet: value: int = driver.applications.k91Wlan.configure.burst.const.carrier.select.get() \n
		Defines the carriers included in the constellation diagram. \n
			:return: carriers: ALL Results for all carriers PILots Results for pilot carriers only integer Specific carrier number only"""
		response = self._core.io.query_str(f'CONFigure:BURSt:CONSt:CARRier:SELect?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LcaptureCls:
	"""Lcapture commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lcapture", core, parent)

	def set(self, state: enums.AutoMode) -> None:
		"""SCPI: TRACe:IQ:LCAPture \n
		Snippet: driver.trace.iq.lcapture.set(state = enums.AutoMode.AUTO) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.enum_scalar_to_str(state, enums.AutoMode)
		self._core.io.write(f'TRACe:IQ:LCAPture {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoMode:
		"""SCPI: TRACe:IQ:LCAPture \n
		Snippet: value: enums.AutoMode = driver.trace.iq.lcapture.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:LCAPture?')
		return Conversions.str_to_scalar_enum(response, enums.AutoMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PeakCls:
	"""Peak commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("peak", core, parent)

	def set(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:SPECtrogram:Y:MAXimum[:PEAK] \n
		Snippet: driver.calculate.marker.spectrogram.y.maximum.peak.set(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command moves a marker vertically to the highest level for the current frequency. The search includes all frames. It
		does not change the horizontal position of the marker. If the marker hasn't been active yet, the command looks for the
		peak level in the whole spectrogram. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:SPECtrogram:Y:MAXimum:PEAK')

	def set_with_opc(self, window=repcap.Window.Default, marker=repcap.Marker.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		"""SCPI: CALCulate<n>:MARKer<m>:SPECtrogram:Y:MAXimum[:PEAK] \n
		Snippet: driver.calculate.marker.spectrogram.y.maximum.peak.set_with_opc(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command moves a marker vertically to the highest level for the current frequency. The search includes all frames. It
		does not change the horizontal position of the marker. If the marker hasn't been active yet, the command looks for the
		peak level in the whole spectrogram. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:SPECtrogram:Y:MAXimum:PEAK', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaxCls:
	"""Max commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("max", core, parent)

	def set(self, payload_max: enums.PayloadMax) -> None:
		"""SCPI: [SENSe]:DEMod:PAYLoad:MAX \n
		Snippet: driver.applications.k149Uwb.sense.demod.payload.max.set(payload_max = enums.PayloadMax.S0) \n
		Selects the maximum payload size. \n
			:param payload_max: S0 | S1 | S2
		"""
		param = Conversions.enum_scalar_to_str(payload_max, enums.PayloadMax)
		self._core.io.write(f'SENSe:DEMod:PAYLoad:MAX {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PayloadMax:
		"""SCPI: [SENSe]:DEMod:PAYLoad:MAX \n
		Snippet: value: enums.PayloadMax = driver.applications.k149Uwb.sense.demod.payload.max.get() \n
		Selects the maximum payload size. \n
			:return: payload_max: S0 | S1 | S2"""
		response = self._core.io.query_str(f'SENSe:DEMod:PAYLoad:MAX?')
		return Conversions.str_to_scalar_enum(response, enums.PayloadMax)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:CLEar[:IMMediate] \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.clear.immediate.set(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command deletes the result of the current limit check. The command works on all limit lines in all measurement
		windows at the same time. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CLEar:IMMediate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsdCls:
	"""Csd commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csd", core, parent)

	def set(self, method: enums.CsdSyncMethod) -> None:
		"""SCPI: CONFigure:WLAN:MIMO:CSD \n
		Snippet: driver.applications.k91Wlan.configure.wlan.mimo.csd.set(method = enums.CsdSyncMethod.APPLy) \n
		Determines whether or not the cyclic shift delay (CSD) is used for timing synchronisation. \n
			:param method: IGNore | APPLy APPLy (Default:) The timing offset estimation result (assuming CSD=0) is used for the subsequent signal analysis. IGNore The timing offset estimation result (assuming CSD=0) is ignored for the subsequent signal analysis.
		"""
		param = Conversions.enum_scalar_to_str(method, enums.CsdSyncMethod)
		self._core.io.write(f'CONFigure:WLAN:MIMO:CSD {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CsdSyncMethod:
		"""SCPI: CONFigure:WLAN:MIMO:CSD \n
		Snippet: value: enums.CsdSyncMethod = driver.applications.k91Wlan.configure.wlan.mimo.csd.get() \n
		Determines whether or not the cyclic shift delay (CSD) is used for timing synchronisation. \n
			:return: method: IGNore | APPLy APPLy (Default:) The timing offset estimation result (assuming CSD=0) is used for the subsequent signal analysis. IGNore The timing offset estimation result (assuming CSD=0) is ignored for the subsequent signal analysis."""
		response = self._core.io.query_str(f'CONFigure:WLAN:MIMO:CSD?')
		return Conversions.str_to_scalar_enum(response, enums.CsdSyncMethod)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GapCls:
	"""Gap commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gap", core, parent)

	def set(self, sts_gap: float) -> None:
		"""SCPI: [SENSe]:DEMod:STS:GAP \n
		Snippet: driver.applications.k149Uwb.sense.demod.sts.gap.set(sts_gap = 1.0) \n
		Gap between payload and STS section in packet configuration 2. \n
			:param sts_gap: numeric value
		"""
		param = Conversions.decimal_value_to_str(sts_gap)
		self._core.io.write(f'SENSe:DEMod:STS:GAP {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DEMod:STS:GAP \n
		Snippet: value: float = driver.applications.k149Uwb.sense.demod.sts.gap.get() \n
		Gap between payload and STS section in packet configuration 2. \n
			:return: sts_gap: numeric value"""
		response = self._core.io.query_str(f'SENSe:DEMod:STS:GAP?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:DPD:UPDate:ALL \n
		Snippet: driver.applications.k18AmplifierEt.configure.dpd.update.all.set() \n
		This command updates the DPD shaping tables on the R&S SMW when new measurement data is available. In addition, this
		command also turns on the DPD ('AM/AM'and'AM/PM') . Using one command only to do those things has the advantage of a
		slightly shorter execution time.
			INTRO_CMD_HELP: Alternatively, you can do that with: \n
			- method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Update.set and
			- method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Amxm.State.set
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
		"""
		self._core.io.write(f'CONFigure:DPD:UPDate:ALL')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:DPD:UPDate:ALL \n
		Snippet: driver.applications.k18AmplifierEt.configure.dpd.update.all.set_with_opc() \n
		This command updates the DPD shaping tables on the R&S SMW when new measurement data is available. In addition, this
		command also turns on the DPD ('AM/AM'and'AM/PM') . Using one command only to do those things has the advantage of a
		slightly shorter execution time.
			INTRO_CMD_HELP: Alternatively, you can do that with: \n
			- method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Update.set and
			- method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Amxm.State.set
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:DPD:UPDate:ALL', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HammersteinCls:
	"""Hammerstein commands group definition. 8 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hammerstein", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def iteration(self):
		"""iteration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iteration'):
			from .Iteration import IterationCls
			self._iteration = IterationCls(self._core, self._cmd_group)
		return self._iteration

	@property
	def order(self):
		"""order commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_order'):
			from .Order import OrderCls
			self._order = OrderCls(self._core, self._cmd_group)
		return self._order

	@property
	def mupGenerator(self):
		"""mupGenerator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mupGenerator'):
			from .MupGenerator import MupGeneratorCls
			self._mupGenerator = MupGeneratorCls(self._core, self._cmd_group)
		return self._mupGenerator

	@property
	def genWaveform(self):
		"""genWaveform commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_genWaveform'):
			from .GenWaveform import GenWaveformCls
			self._genWaveform = GenWaveformCls(self._core, self._cmd_group)
		return self._genWaveform

	@property
	def nonlinearity(self):
		"""nonlinearity commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_nonlinearity'):
			from .Nonlinearity import NonlinearityCls
			self._nonlinearity = NonlinearityCls(self._core, self._cmd_group)
		return self._nonlinearity

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	def clone(self) -> 'HammersteinCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HammersteinCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, position: int, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:IQ:STATe \n
		Snippet: driver.applications.k9X11Ad.massMemory.load.iq.state.set(position = 1, filename = '1') \n
		This command restores I/Q data from a file. The file extension is *.iq.tar. \n
			:param position: No help available
			:param filename: string String containing the path and name of the source file.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('position', position, DataType.Integer), ArgSingle('filename', filename, DataType.String))
		self._core.io.write(f'MMEMory:LOAD:IQ:STATe {param}'.rstrip())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RuConfigCls:
	"""RuConfig commands group definition. 21 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ruConfig", core, parent)

	@property
	def ehtPpdu(self):
		"""ehtPpdu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ehtPpdu'):
			from .EhtPpdu import EhtPpduCls
			self._ehtPpdu = EhtPpduCls(self._core, self._cmd_group)
		return self._ehtPpdu

	@property
	def hePpdu(self):
		"""hePpdu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hePpdu'):
			from .HePpdu import HePpduCls
			self._hePpdu = HePpduCls(self._core, self._cmd_group)
		return self._hePpdu

	@property
	def nheLtf(self):
		"""nheLtf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nheLtf'):
			from .NheLtf import NheLtfCls
			self._nheLtf = NheLtfCls(self._core, self._cmd_group)
		return self._nheLtf

	@property
	def count(self):
		"""count commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def refresh(self):
		"""refresh commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refresh'):
			from .Refresh import RefreshCls
			self._refresh = RefreshCls(self._core, self._cmd_group)
		return self._refresh

	@property
	def segment(self):
		"""segment commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_segment'):
			from .Segment import SegmentCls
			self._segment = SegmentCls(self._core, self._cmd_group)
		return self._segment

	def clone(self) -> 'RuConfigCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RuConfigCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SthresholdCls:
	"""Sthreshold commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sthreshold", core, parent)

	def set(self, threshold: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:PPSPectrum:STHReshold \n
		Snippet: driver.applications.k6Pulse.calculate.ppSpectrum.sthreshold.set(threshold = 1.0, window = repcap.Window.Default) \n
		Defines the minimum section size. Sections that are smaller than the threshold are ignored and considered to be part of
		the detected gap. For more information see 'Parameter spectrum calculation'. \n
			:param threshold: Minimum section size as a percentage of the block size (see method RsFsw.Applications.K6_Pulse.Calculate.Pspectrum.BlockSize.set) Range: 0 to 100
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(threshold)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:PPSPectrum:STHReshold {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:PPSPectrum:STHReshold \n
		Snippet: value: float = driver.applications.k6Pulse.calculate.ppSpectrum.sthreshold.get(window = repcap.Window.Default) \n
		Defines the minimum section size. Sections that are smaller than the threshold are ignored and considered to be part of
		the detected gap. For more information see 'Parameter spectrum calculation'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: threshold: Minimum section size as a percentage of the block size (see method RsFsw.Applications.K6_Pulse.Calculate.Pspectrum.BlockSize.set) Range: 0 to 100"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:PPSPectrum:STHReshold?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EfilterCls:
	"""Efilter commands group definition. 4 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("efilter", core, parent)

	@property
	def fparameters(self):
		"""fparameters commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_fparameters'):
			from .Fparameters import FparametersCls
			self._fparameters = FparametersCls(self._core, self._cmd_group)
		return self._fparameters

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def preset(self) -> None:
		"""SCPI: [SENSe]:NR5G:EFILter:PRESet \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.efilter.preset() \n
		This command removes all event filters. \n
		"""
		self._core.io.write(f'SENSe:NR5G:EFILter:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:NR5G:EFILter:PRESet \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.efilter.preset_with_opc() \n
		This command removes all event filters. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:NR5G:EFILter:PRESet', opc_timeout_ms)

	def clone(self) -> 'EfilterCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EfilterCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal.RepeatedCapability import RepeatedCapability
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllocationCls:
	"""Allocation commands group definition. 41 total commands, 13 Subgroups, 1 group commands
	Repeated Capability: Allocation, default value after init: Allocation.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("allocation", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_allocation_get', 'repcap_allocation_set', repcap.Allocation.Nr0)

	def repcap_allocation_set(self, allocation: repcap.Allocation) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Allocation.Default
		Default value after init: Allocation.Nr0"""
		self._cmd_group.set_repcap_enum_value(allocation)

	def repcap_allocation_get(self) -> repcap.Allocation:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ccoding(self):
		"""ccoding commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import CcodingCls
			self._ccoding = CcodingCls(self._core, self._cmd_group)
		return self._ccoding

	@property
	def clMapping(self):
		"""clMapping commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_clMapping'):
			from .ClMapping import ClMappingCls
			self._clMapping = ClMappingCls(self._core, self._cmd_group)
		return self._clMapping

	@property
	def copy(self):
		"""copy commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_copy'):
			from .Copy import CopyCls
			self._copy = CopyCls(self._core, self._cmd_group)
		return self._copy

	@property
	def dmrs(self):
		"""dmrs commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmrs'):
			from .Dmrs import DmrsCls
			self._dmrs = DmrsCls(self._core, self._cmd_group)
		return self._dmrs

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def ptrs(self):
		"""ptrs commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_ptrs'):
			from .Ptrs import PtrsCls
			self._ptrs = PtrsCls(self._core, self._cmd_group)
		return self._ptrs

	@property
	def rbCount(self):
		"""rbCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbCount'):
			from .RbCount import RbCountCls
			self._rbCount = RbCountCls(self._core, self._cmd_group)
		return self._rbCount

	@property
	def rbOffset(self):
		"""rbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbOffset'):
			from .RbOffset import RbOffsetCls
			self._rbOffset = RbOffsetCls(self._core, self._cmd_group)
		return self._rbOffset

	@property
	def scount(self):
		"""scount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scount'):
			from .Scount import ScountCls
			self._scount = ScountCls(self._core, self._cmd_group)
		return self._scount

	@property
	def scrambling(self):
		"""scrambling commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_scrambling'):
			from .Scrambling import ScramblingCls
			self._scrambling = ScramblingCls(self._core, self._cmd_group)
		return self._scrambling

	@property
	def soffset(self):
		"""soffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_soffset'):
			from .Soffset import SoffsetCls
			self._soffset = SoffsetCls(self._core, self._cmd_group)
		return self._soffset

	@property
	def ueId(self):
		"""ueId commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ueId'):
			from .UeId import UeIdCls
			self._ueId = UeIdCls(self._core, self._cmd_group)
		return self._ueId

	def copy_to(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:COPY \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.frame.bwPart.slot.allocation.copy_to(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command copies a PUSCH configuration to other slots.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Number of configurable slots > 1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Cslot.set) .
			- Select paste mode (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Slot.Allocation.Copy.Mode.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
		"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		self._core.io.write(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:COPY')

	def copy_to_with_opc(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default, opc_timeout_ms: int = -1) -> None:
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:COPY \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.frame.bwPart.slot.allocation.copy_to_with_opc(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command copies a PUSCH configuration to other slots.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Number of configurable slots > 1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Cslot.set) .
			- Select paste mode (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Slot.Allocation.Copy.Mode.set) . \n
		Same as copy_to, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:COPY', opc_timeout_ms)

	def clone(self) -> 'AllocationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AllocationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CaptureCls:
	"""Capture commands group definition. 5 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("capture", core, parent)

	@property
	def default(self):
		"""default commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_default'):
			from .Default import DefaultCls
			self._default = DefaultCls(self._core, self._cmd_group)
		return self._default

	@property
	def fset(self):
		"""fset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fset'):
			from .Fset import FsetCls
			self._fset = FsetCls(self._core, self._cmd_group)
		return self._fset

	@property
	def length(self):
		"""length commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def oversampling(self):
		"""oversampling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_oversampling'):
			from .Oversampling import OversamplingCls
			self._oversampling = OversamplingCls(self._core, self._cmd_group)
		return self._oversampling

	@property
	def preset(self):
		"""preset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_preset'):
			from .Preset import PresetCls
			self._preset = PresetCls(self._core, self._cmd_group)
		return self._preset

	def clone(self) -> 'CaptureCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CaptureCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandCls:
	"""Band commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("band", core, parent)

	def set(self, range_py: enums.LowHigh, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:MSR:BAND \n
		Snippet: driver.applications.k14Xnr5G.sense.espectrum.msr.band.set(range_py = enums.LowHigh.HIGH, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param range_py: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		param = Conversions.enum_scalar_to_str(range_py, enums.LowHigh)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:MSR:BAND {param}')

	# noinspection PyTypeChecker
	def get(self, subBlock=repcap.SubBlock.Default) -> enums.LowHigh:
		"""SCPI: [SENSe]:ESPectrum<sb>:MSR:BAND \n
		Snippet: value: enums.LowHigh = driver.applications.k14Xnr5G.sense.espectrum.msr.band.get(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:return: range_py: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:MSR:BAND?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TcpipCls:
	"""Tcpip commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tcpip", core, parent)

	def set(self, tcpip: str) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:TCPip \n
		Snippet: driver.applications.k18AmplifierEt.system.communicate.rdevice.oscilloscope.tcpip.set(tcpip = '1') \n
		No command help available \n
			:param tcpip: No help available
		"""
		param = Conversions.value_to_quoted_str(tcpip)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:TCPip {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:TCPip \n
		Snippet: value: str = driver.applications.k18AmplifierEt.system.communicate.rdevice.oscilloscope.tcpip.get() \n
		No command help available \n
			:return: tcpip: No help available"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:TCPip?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	@property
	def factor(self):
		"""factor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_factor'):
			from .Factor import FactorCls
			self._factor = FactorCls(self._core, self._cmd_group)
		return self._factor

	def set(self, coupling_type: enums.FrequencyCouplingLinkA) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:LINK \n
		Snippet: driver.applications.k10Xlte.sense.frequency.center.step.link.set(coupling_type = enums.FrequencyCouplingLinkA.OFF) \n
		No command help available \n
			:param coupling_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(coupling_type, enums.FrequencyCouplingLinkA)
		self._core.io.write(f'SENSe:FREQuency:CENTer:STEP:LINK {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FrequencyCouplingLinkA:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:LINK \n
		Snippet: value: enums.FrequencyCouplingLinkA = driver.applications.k10Xlte.sense.frequency.center.step.link.get() \n
		No command help available \n
			:return: coupling_type: No help available"""
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer:STEP:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.FrequencyCouplingLinkA)

	def clone(self) -> 'LinkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LinkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:SANalyzer:ATTenuation:AUTO \n
		Snippet: driver.inputPy.sanalyzer.attenuation.auto.set(state = False, inputIx = repcap.InputIx.Default) \n
		Enables or disables automatic configuration of attenuation at the analyzer input for an active external frontend.
		By default, the attenuation settings are applied at the input of the external frontend, see method RsFsw.Applications.
		K10x_Lte.InputPy.Attenuation.Auto.set and method RsFsw.Applications.K10x_Lte.InputPy.Attenuation.set. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Auto mode for analyzer attenuation is disabled. Allows you to configure attenuation at the analyzer using method RsFsw.InputPy.Sanalyzer.Attenuation.set. ON | 1 Auto mode for analyzer attenuation is enabled. No attenuation is configured at the analyzer.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.bool_to_str(state)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:SANalyzer:ATTenuation:AUTO {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 30 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def fmError(self):
		"""fmError commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmError'):
			from .FmError import FmErrorCls
			self._fmError = FmErrorCls(self._core, self._cmd_group)
		return self._fmError

	@property
	def maxFm(self):
		"""maxFm commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_maxFm'):
			from .MaxFm import MaxFmCls
			self._maxFm = MaxFmCls(self._core, self._cmd_group)
		return self._maxFm

	@property
	def rmsFm(self):
		"""rmsFm commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_rmsFm'):
			from .RmsFm import RmsFmCls
			self._rmsFm = RmsFmCls(self._core, self._cmd_group)
		return self._rmsFm

	@property
	def avgFm(self):
		"""avgFm commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_avgFm'):
			from .AvgFm import AvgFmCls
			self._avgFm = AvgFmCls(self._core, self._cmd_group)
		return self._avgFm

	@property
	def relFrequency(self):
		"""relFrequency commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_relFrequency'):
			from .RelFrequency import RelFrequencyCls
			self._relFrequency = RelFrequencyCls(self._core, self._cmd_group)
		return self._relFrequency

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DutLimitCls:
	"""DutLimit commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dutLimit", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, level: float) -> None:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel:DUTLimit \n
		Snippet: driver.applications.k17Mcgd.configure.generator.mcgd.level.dutLimit.set(level = 1.0) \n
		Sets or queries the maximum input power (peak envelope power, 'PEP') that is currently allowed by the DUT and that is
		specified on the generator. The generator output does not exceed this value. \n
			:param level: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'CONFigure:GENerator:MCGD:LEVel:DUTLimit {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel:DUTLimit \n
		Snippet: value: float = driver.applications.k17Mcgd.configure.generator.mcgd.level.dutLimit.get() \n
		Sets or queries the maximum input power (peak envelope power, 'PEP') that is currently allowed by the DUT and that is
		specified on the generator. The generator output does not exceed this value. \n
			:return: level: Unit: dBm"""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:LEVel:DUTLimit?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'DutLimitCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DutLimitCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AbsoluteCls:
	"""Absolute commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("absolute", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, lower_limit: float, upper_limit: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:ACHannel:ABSolute \n
		Snippet: driver.calculate.limit.acPower.achannel.absolute.set(lower_limit = 1.0, upper_limit = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command defines the absolute limit of the adjacent channels. If you have defined an absolute limit as well as a
		relative limit, the R&S FSW uses the lower value for the limit check. \n
			:param lower_limit: The limit of the lower adjacent channel. Range: -200 dBm to 200 dBm, Unit: dBm
			:param upper_limit: The limit of the upper adjacent channel. Range: -200 dBm to 200 dBm, Unit: dBm
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('lower_limit', lower_limit, DataType.Float), ArgSingle('upper_limit', upper_limit, DataType.Float))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:ACHannel:ABSolute {param}'.rstrip())

	# noinspection PyTypeChecker
	class Limits(StructBase):
		"""Response structure. Fields: \n
			- Lower_Limit: float: The limit of the lower adjacent channel. Range: -200 dBm to 200 dBm, Unit: dBm
			- Upper_Limit: float: The limit of the upper adjacent channel. Range: -200 dBm to 200 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower_Limit'),
			ArgStruct.scalar_float('Upper_Limit')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower_Limit: float = None
			self.Upper_Limit: float = None

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> Limits:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:ACHannel:ABSolute \n
		Snippet: value: Limits = driver.calculate.limit.acPower.achannel.absolute.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command defines the absolute limit of the adjacent channels. If you have defined an absolute limit as well as a
		relative limit, the R&S FSW uses the lower value for the limit check. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: structure: for return value, see the help for Limits structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:ACHannel:ABSolute?', self.__class__.Limits())

	def clone(self) -> 'AbsoluteCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AbsoluteCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:TRISe:MINimum \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.trise.minimum.get() \n
		This command returns the average, maximum or minimum burst rise time in seconds. This command is only applicable to
		IEEE802.11b & IEEE802.11g (DSSS) signals. For details see 'Modulation accuracy, flatness and tolerance parameters'. \n
			:return: result: list"""
		response = self._core.io.query_str(f'FETCh:BURSt:TRISe:MINimum?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:DIQ[:STATe] \n
		Snippet: driver.applications.k70Vsa.output.diq.state.set(state = False, outputConnector = repcap.OutputConnector.Default) \n
		This command turns continuous output of I/Q data to the optional 'Digital Baseband' interface on and off.
		Using the digital input and digital output simultaneously is not possible. If digital baseband output is active, the
		sample rate is restricted to 100 MHz (200 MHz if enhanced mode is possible; max. 160 MHz bandwidth) . \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.bool_to_str(state)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:DIQ:STATe {param}')

	def get(self, outputConnector=repcap.OutputConnector.Default) -> bool:
		"""SCPI: OUTPut<up>:DIQ[:STATe] \n
		Snippet: value: bool = driver.applications.k70Vsa.output.diq.state.get(outputConnector = repcap.OutputConnector.Default) \n
		This command turns continuous output of I/Q data to the optional 'Digital Baseband' interface on and off.
		Using the digital input and digital output simultaneously is not possible. If digital baseband output is active, the
		sample rate is restricted to 100 MHz (200 MHz if enhanced mode is possible; max. 160 MHz bandwidth) . \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:DIQ:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LdirectionCls:
	"""Ldirection commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ldirection", core, parent)

	def set(self, mode: enums.DlUlDirection) -> None:
		"""SCPI: CONFigure[:NR5G]:LDIRection \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.ldirection.set(mode = enums.DlUlDirection.DL) \n
		This command selects the link direction you want to analyze. \n
			:param mode: DL Selects the downlink application to analyze 5G NR downlink signals. Requires option R&S FSW-K144. UL Selects the uplink application to analyze 5G NR uplink signals. Requires option R&S FSW-K145.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.DlUlDirection)
		self._core.io.write(f'CONFigure:NR5G:LDIRection {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DlUlDirection:
		"""SCPI: CONFigure[:NR5G]:LDIRection \n
		Snippet: value: enums.DlUlDirection = driver.applications.k14Xnr5G.configure.nr5G.ldirection.get() \n
		This command selects the link direction you want to analyze. \n
			:return: mode: DL Selects the downlink application to analyze 5G NR downlink signals. Requires option R&S FSW-K144. UL Selects the uplink application to analyze 5G NR uplink signals. Requires option R&S FSW-K145."""
		response = self._core.io.query_str(f'CONFigure:NR5G:LDIRection?')
		return Conversions.str_to_scalar_enum(response, enums.DlUlDirection)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, time: float) -> None:
		"""SCPI: [SENSe]:SWEep:TIME \n
		Snippet: driver.sense.sweep.time.set(time = 1.0) \n
		This command defines the sweep time. It automatically decouples the time from any other settings. In the Spectrum
		application, the command decouples the sweep time from the span and resolution and video bandwidths. Note that this
		command queries only the time required to capture the data, not to process it. To obtain an estimation of the total
		capture and processing time, use the [SENSe:]SWEep:DURation? command. \n
			:param time: refer to data sheet Unit: S
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SENSe:SWEep:TIME {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:TIME \n
		Snippet: value: float = driver.sense.sweep.time.get() \n
		This command defines the sweep time. It automatically decouples the time from any other settings. In the Spectrum
		application, the command decouples the sweep time from the span and resolution and video bandwidths. Note that this
		command queries only the time required to capture the data, not to process it. To obtain an estimation of the total
		capture and processing time, use the [SENSe:]SWEep:DURation? command. \n
			:return: time: refer to data sheet Unit: S"""
		response = self._core.io.query_str(f'SENSe:SWEep:TIME?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'TimeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TimeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, trace_mode: enums.TraceModeC, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:MODE \n
		Snippet: driver.applications.k18AmplifierEt.display.window.subwindow.trace.mode.set(trace_mode = enums.TraceModeC.AVERage, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command selects the traces to be displayed in the graphical result displays. \n
			:param trace_mode: Available traces depend on the result display. AVERage The average is formed over several measurements. BLANk Removes the selected trace from the display. MAXHold The maximum value is determined over several measurements and displayed. The R&S FSW saves each trace point in the trace memory only if the new value is greater than the previous one. MINHold The minimum value is determined from several measurements and displayed. The R&S FSW saves each trace point in the trace memory only if the new value is lower than the previous one. VIEW The current contents of the trace memory are frozen and displayed. WRITe Overwrite mode (default) : the trace is overwritten by each measurement.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(trace_mode, enums.TraceModeC)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> enums.TraceModeC:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:MODE \n
		Snippet: value: enums.TraceModeC = driver.applications.k18AmplifierEt.display.window.subwindow.trace.mode.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command selects the traces to be displayed in the graphical result displays. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: trace_mode: Available traces depend on the result display. AVERage The average is formed over several measurements. BLANk Removes the selected trace from the display. MAXHold The maximum value is determined over several measurements and displayed. The R&S FSW saves each trace point in the trace memory only if the new value is greater than the previous one. MINHold The minimum value is determined from several measurements and displayed. The R&S FSW saves each trace point in the trace memory only if the new value is lower than the previous one. VIEW The current contents of the trace memory are frozen and displayed. WRITe Overwrite mode (default) : the trace is overwritten by each measurement."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TraceModeC)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PayloadCls:
	"""Payload commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("payload", core, parent)

	@property
	def apackets(self):
		"""apackets commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apackets'):
			from .Apackets import ApacketsCls
			self._apackets = ApacketsCls(self._core, self._cmd_group)
		return self._apackets

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: FETCh<n>:PACKet:DATA:PAYLoad \n
		Snippet: value: str = driver.applications.k149Uwb.fetch.packet.data.payload.get(window = repcap.Window.Default) \n
		Returns the payload of the packet in hexadecimal format. In accordance with IEEE 802.15.4, the LSB of each octet of the
		payload is output first. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fetch')
			:return: result: Use n to select a 'Packet Insights' result display. Window"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'FETCh{window_cmd_val}:PACKet:DATA:PAYLoad?')
		return trim_str_response(response)

	def clone(self) -> 'PayloadCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PayloadCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def ppdu(self):
		"""ppdu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ppdu'):
			from .Ppdu import PpduCls
			self._ppdu = PpduCls(self._core, self._cmd_group)
		return self._ppdu

	@property
	def sc(self):
		"""sc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sc'):
			from .Sc import ScCls
			self._sc = ScCls(self._core, self._cmd_group)
		return self._sc

	@property
	def ru(self):
		"""ru commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ru'):
			from .Ru import RuCls
			self._ru = RuCls(self._core, self._cmd_group)
		return self._ru

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AngleCls:
	"""Angle commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("angle", core, parent)

	def set(self, unit: enums.AngleUnit, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:UNIT:ANGLe \n
		Snippet: driver.applications.k70Vsa.calculate.unit.angle.set(unit = enums.AngleUnit.DEG, window = repcap.Window.Default) \n
		This command selects the global unit for phase results. \n
			:param unit: DEG | RAD
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.AngleUnit)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:UNIT:ANGLe {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.AngleUnit:
		"""SCPI: CALCulate<n>:UNIT:ANGLe \n
		Snippet: value: enums.AngleUnit = driver.applications.k70Vsa.calculate.unit.angle.get(window = repcap.Window.Default) \n
		This command selects the global unit for phase results. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: unit: DEG | RAD"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNIT:ANGLe?')
		return Conversions.str_to_scalar_enum(response, enums.AngleUnit)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:DDEM:SPECtrum[:STATe] \n
		Snippet: driver.applications.k70Vsa.calculate.ddem.spectrum.state.set(state = False, window = repcap.Window.Default) \n
		This command switches the result type transformation to spectrum mode. Spectral evaluation is available for the following
		result types:
			INTRO_CMD_HELP: The I/Q data file must be in one of the following supported formats: \n
			- MAGNitude
			- PHASe/UPHase
			- FREQuency
			- Real/Imag (RIMAG)
		The result types are defined using the method RsFsw.Calculate.FormatPy.set command (see method RsFsw.Calculate.FormatPy.
		set) . \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:DDEM:SPECtrum:STATe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:DDEM:SPECtrum[:STATe] \n
		Snippet: value: bool = driver.applications.k70Vsa.calculate.ddem.spectrum.state.get(window = repcap.Window.Default) \n
		This command switches the result type transformation to spectrum mode. Spectral evaluation is available for the following
		result types:
			INTRO_CMD_HELP: The I/Q data file must be in one of the following supported formats: \n
			- MAGNitude
			- PHASe/UPHase
			- FREQuency
			- Real/Imag (RIMAG)
		The result types are defined using the method RsFsw.Calculate.FormatPy.set command (see method RsFsw.Calculate.FormatPy.
		set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DDEM:SPECtrum:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:CLOCk:OFFSet \n
		Snippet: value: float = driver.applications.k17Mcgd.sense.clock.offset.get() \n
		Frequency spread of the captured multi-carrier signal compared to the setting given by multi-carrier signal description.
		This frequency spread is estimated and compensated when using carrier estimation mode 'All Carriers'. The clock offset
		reading shows the influence of Doppler shift in satellite communication measurements. \n
			:return: clock_offset: Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:CLOCk:OFFSet?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 8 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	@property
	def fixed(self):
		"""fixed commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fixed'):
			from .Fixed import FixedCls
			self._fixed = FixedCls(self._core, self._cmd_group)
		return self._fixed

	@property
	def hysteresis(self):
		"""hysteresis commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_hysteresis'):
			from .Hysteresis import HysteresisCls
			self._hysteresis = HysteresisCls(self._core, self._cmd_group)
		return self._hysteresis

	@property
	def memory(self):
		"""memory commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_memory'):
			from .Memory import MemoryCls
			self._memory = MemoryCls(self._core, self._cmd_group)
		return self._memory

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	def set(self, state: bool, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:AUTO \n
		Snippet: driver.applications.k91Wlan.display.window.subwindow.trace.y.scale.auto.set(state = False, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param state: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:AUTO {param}')

	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:AUTO \n
		Snippet: value: bool = driver.applications.k91Wlan.display.window.subwindow.trace.y.scale.auto.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: state: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:AUTO?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'AutoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AutoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:CARRier:OFFSet \n
		Snippet: value: float = driver.applications.k17Mcgd.sense.carrier.offset.get() \n
		Frequency offset of the captured multi-carrier signal compared to the setting given by multi-carrier signal description.
		This frequency offset is estimated and compensated when using carrier estimation modes 'Offset' or 'All Carriers'. \n
			:return: carrier_offset: Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:CARRier:OFFSet?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: int, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:IQ:STATe \n
		Snippet: driver.applications.k91Wlan.massMemory.load.iq.state.set(state = 1, filename = '1') \n
		This command restores I/Q data from a file. The file extension is *.iqw. \n
			:param state: No help available
			:param filename: string String containing the path and name of the source file.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Integer), ArgSingle('filename', filename, DataType.String))
		self._core.io.write(f'MMEMory:LOAD:IQ:STATe {param}'.rstrip())

	# noinspection PyTypeChecker
	class StateStruct(StructBase):
		"""Response structure. Fields: \n
			- State: int: No parameter help available
			- Filename: str: string String containing the path and name of the source file."""
		__meta_args_list = [
			ArgStruct.scalar_int('State'),
			ArgStruct.scalar_str('Filename')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.State: int = None
			self.Filename: str = None

	def get(self) -> StateStruct:
		"""SCPI: MMEMory:LOAD:IQ:STATe \n
		Snippet: value: StateStruct = driver.applications.k91Wlan.massMemory.load.iq.state.get() \n
		This command restores I/Q data from a file. The file extension is *.iqw. \n
			:return: structure: for return value, see the help for StateStruct structure arguments."""
		return self._core.io.query_struct(f'MMEMory:LOAD:IQ:STATe?', self.__class__.StateStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ClockCls:
	"""Clock commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clock", core, parent)

	def get(self, notch=repcap.Notch.Default) -> float:
		"""SCPI: CONFigure:GENerator:NPRatio:NOTCh<notch>:CLOCk \n
		Snippet: value: float = driver.configure.generator.npratio.notch.clock.get(notch = repcap.Notch.Default) \n
		Queries the generator clock frequency. \n
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')
			:return: clock_frequency: 1..n irrelevant"""
		notch_cmd_val = self._cmd_group.get_repcap_cmd_value(notch, repcap.Notch)
		response = self._core.io.query_str(f'CONFigure:GENerator:NPRatio:NOTCh{notch_cmd_val}:CLOCk?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NheLtfCls:
	"""NheLtf commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nheLtf", core, parent)

	def set(self, ru_config_nhe_ltf: enums.RuConfigNheLtf) -> None:
		"""SCPI: CONFigure:WLAN:RUConfig:NHELtf \n
		Snippet: driver.applications.k91Wlan.configure.wlan.ruConfig.nheLtf.set(ru_config_nhe_ltf = enums.RuConfigNheLtf.S1) \n
		Defines the length of the high-efficiency long training field (for trigger-based uplink PPDUs only) .
		For more information see 'HE Trigger-based PPDUs'. \n
			:param ru_config_nhe_ltf: STA | S1 | S2 | S4 | S6 | S8 STA The station configuration defines the used length. S1 | S2 | S4 | S6 | S8 The LTF of the PPDUs have a fixed length (1 / 2 / 4 / 6 / 8 symbols) .
		"""
		param = Conversions.enum_scalar_to_str(ru_config_nhe_ltf, enums.RuConfigNheLtf)
		self._core.io.write(f'CONFigure:WLAN:RUConfig:NHELtf {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.RuConfigNheLtf:
		"""SCPI: CONFigure:WLAN:RUConfig:NHELtf \n
		Snippet: value: enums.RuConfigNheLtf = driver.applications.k91Wlan.configure.wlan.ruConfig.nheLtf.get() \n
		Defines the length of the high-efficiency long training field (for trigger-based uplink PPDUs only) .
		For more information see 'HE Trigger-based PPDUs'. \n
			:return: ru_config_nhe_ltf: STA | S1 | S2 | S4 | S6 | S8 STA The station configuration defines the used length. S1 | S2 | S4 | S6 | S8 The LTF of the PPDUs have a fixed length (1 / 2 / 4 / 6 / 8 symbols) ."""
		response = self._core.io.query_str(f'CONFigure:WLAN:RUConfig:NHELtf?')
		return Conversions.str_to_scalar_enum(response, enums.RuConfigNheLtf)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FftSubspanCls:
	"""FftSubspan commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fftSubspan", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:FFTSubspan \n
		Snippet: value: float = driver.sense.sweep.fftSubspan.get() \n
		Returns the number of FFT subspans required to cover the entire measurement range (read-only) . See also 'Number of
		subspans'. Only available in FFT sweep mode in the Spectrum application, and not for SEM, ACLR, or Spurious emissions
		measurements. \n
			:return: no_of_partial_spans: integer"""
		response = self._core.io.query_str(f'SENSe:SWEep:FFTSubspan?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GimbalanceCls:
	"""Gimbalance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gimbalance", core, parent)

	def set(self, unit: enums.UnitMode) -> None:
		"""SCPI: UNIT:GIMBalance \n
		Snippet: driver.applications.k91Wlan.unit.gimbalance.set(unit = enums.UnitMode.DB) \n
		This command specifies the units for gain imbalance results For details see 'Modulation accuracy, flatness and tolerance
		parameters'. \n
			:param unit: DB | PCT
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.UnitMode)
		self._core.io.write(f'UNIT:GIMBalance {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.UnitMode:
		"""SCPI: UNIT:GIMBalance \n
		Snippet: value: enums.UnitMode = driver.applications.k91Wlan.unit.gimbalance.get() \n
		This command specifies the units for gain imbalance results For details see 'Modulation accuracy, flatness and tolerance
		parameters'. \n
			:return: unit: DB | PCT"""
		response = self._core.io.query_str(f'UNIT:GIMBalance?')
		return Conversions.str_to_scalar_enum(response, enums.UnitMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def memory(self):
		"""memory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_memory'):
			from .Memory import MemoryCls
			self._memory = MemoryCls(self._core, self._cmd_group)
		return self._memory

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	def get(self) -> str:
		"""SCPI: TRACe:IQ:DATA \n
		Snippet: value: str = driver.applications.k60Transient.trace.iq.data.get() \n
		This command initiates a measurement with the current settings and returns the captured data from I/Q measurements. This
		command corresponds to: INIT:IMM;*WAI;method RsFsw.Trace.Iq.Data.Memory.get_ However, the method RsFsw.Trace.Iq.Data.get_
		command is quicker in comparison. \n
			:return: results: Measured voltage for I and Q component for each sample that has been captured during the measurement. For more information see 'I/Q Processing Modes'. Unit: V"""
		response = self._core.io.query_str(f'TRACe:IQ:DATA?')
		return trim_str_response(response)

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, carrier: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: [SENSe][:LTE][:CC<cc>]:CARRier:SELect \n
		Snippet: driver.applications.k10Xlte.sense.lte.cc.carrier.select.set(carrier = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command filters the results in the constellation diagram by a certain subcarrier. \n
			:param carrier: ALL Shows the results for all subcarriers. numeric_value (integer only) Shows the results for a single subcarrier.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(carrier)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'SENSe:LTE:CC{carrierComponent_cmd_val}:CARRier:SELect {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: [SENSe][:LTE][:CC<cc>]:CARRier:SELect \n
		Snippet: value: float = driver.applications.k10Xlte.sense.lte.cc.carrier.select.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command filters the results in the constellation diagram by a certain subcarrier. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: carrier: ALL Shows the results for all subcarriers. numeric_value (integer only) Shows the results for a single subcarrier."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'SENSe:LTE:CC{carrierComponent_cmd_val}:CARRier:SELect?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ContinuousCls:
	"""Continuous commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("continuous", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INITiate:CONTinuous \n
		Snippet: driver.initiate.continuous.set(state = False) \n
		This command controls the sweep mode for an individual channel. Note that in single sweep mode, you can synchronize to
		the end of the measurement with *OPC, *OPC? or *WAI. In continuous sweep mode, synchronization to the end of the
		measurement is not possible. Thus, it is not recommended that you use continuous sweep mode in remote control, as results
		like trace data or markers are only valid after a single sweep end synchronization. For details on synchronization see
		Remote control via SCPI. If the sweep mode is changed for a channel while the Sequencer is active (see method RsFsw.
		Initiate.Sequencer.Immediate.set) the mode is only considered the next time the measurement in that channel is activated
		by the Sequencer. \n
			:param state: ON | OFF | 0 | 1 ON | 1 Continuous sweep OFF | 0 Single sweep
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INITiate:CONTinuous {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XadjustCls:
	"""Xadjust commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("xadjust", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:LIST:XADJust \n
		Snippet: driver.sense.listPy.xadjust.set() \n
		Sets the x-axis range for the spurious emission measurement from the start frequency of the first sweep range to the stop
		frequency of the last sweep range. \n
		"""
		self._core.io.write(f'SENSe:LIST:XADJust')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:LIST:XADJust \n
		Snippet: driver.sense.listPy.xadjust.set_with_opc() \n
		Sets the x-axis range for the spurious emission measurement from the start frequency of the first sweep range to the stop
		frequency of the last sweep range. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:LIST:XADJust', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SignalCls:
	"""Signal commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("signal", core, parent)

	def set(self, bias: enums.State) -> None:
		"""SCPI: [SENSe]:MIXer:SIGNal \n
		Snippet: driver.applications.k9X11Ad.sense.mixer.signal.set(bias = enums.State.ALL) \n
		This command specifies whether automatic signal detection is active or not. Note that automatic signal identification is
		only available for measurements that perform frequency sweeps (not in vector signal analysis or the I/Q Analyzer, for
		instance) . \n
			:param bias: No help available
		"""
		param = Conversions.enum_scalar_to_str(bias, enums.State)
		self._core.io.write(f'SENSe:MIXer:SIGNal {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.State:
		"""SCPI: [SENSe]:MIXer:SIGNal \n
		Snippet: value: enums.State = driver.applications.k9X11Ad.sense.mixer.signal.get() \n
		This command specifies whether automatic signal detection is active or not. Note that automatic signal identification is
		only available for measurements that perform frequency sweeps (not in vector signal analysis or the I/Q Analyzer, for
		instance) . \n
			:return: bias: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:SIGNal?')
		return Conversions.str_to_scalar_enum(response, enums.State)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INPut:GAIN:STATe \n
		Snippet: driver.applications.k40PhaseNoise.inputPy.gain.state.set(state = False) \n
		This command turns the internal preamplifier on and off. It requires the optional preamplifier hardware. Note that if an
		optional external preamplifier is activated, the internal preamplifier is automatically disabled, and vice versa.
		If option R&S FSW-B22 is installed, the preamplifier is only active below 7 GHz. If option R&S FSW-B24 is installed, the
		preamplifier is active for all frequencies. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INPut:GAIN:STATe {param}')

	def get(self) -> bool:
		"""SCPI: INPut:GAIN:STATe \n
		Snippet: value: bool = driver.applications.k40PhaseNoise.inputPy.gain.state.get() \n
		This command turns the internal preamplifier on and off. It requires the optional preamplifier hardware. Note that if an
		optional external preamplifier is activated, the internal preamplifier is automatically disabled, and vice versa.
		If option R&S FSW-B22 is installed, the preamplifier is only active below 7 GHz. If option R&S FSW-B24 is installed, the
		preamplifier is active for all frequencies. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'INPut:GAIN:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OptimizationCls:
	"""Optimization commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("optimization", core, parent)

	def set(self, state: enums.FrameOptimize) -> None:
		"""SCPI: [SENSe]:NR5G:FRAMe:OPTimization \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.frame.optimization.set(state = enums.FrameOptimize.DYNamic) \n
		This command selects the data capture method for combined measurements. \n
			:param state: DYNamic Separate capture of carrier and neighboring channels. SPEed Capture all channels in one take.
		"""
		param = Conversions.enum_scalar_to_str(state, enums.FrameOptimize)
		self._core.io.write(f'SENSe:NR5G:FRAMe:OPTimization {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FrameOptimize:
		"""SCPI: [SENSe]:NR5G:FRAMe:OPTimization \n
		Snippet: value: enums.FrameOptimize = driver.applications.k14Xnr5G.sense.nr5G.frame.optimization.get() \n
		This command selects the data capture method for combined measurements. \n
			:return: state: DYNamic Separate capture of carrier and neighboring channels. SPEed Capture all channels in one take."""
		response = self._core.io.query_str(f'SENSe:NR5G:FRAMe:OPTimization?')
		return Conversions.str_to_scalar_enum(response, enums.FrameOptimize)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SblockCls:
	"""Sblock commands group definition. 7 total commands, 7 Subgroups, 0 group commands
	Repeated Capability: SubBlock, default value after init: SubBlock.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sblock", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_subBlock_get', 'repcap_subBlock_set', repcap.SubBlock.Nr1)

	def repcap_subBlock_set(self, subBlock: repcap.SubBlock) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SubBlock.Default
		Default value after init: SubBlock.Nr1"""
		self._cmd_group.set_repcap_enum_value(subBlock)

	def repcap_subBlock_get(self) -> repcap.SubBlock:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def bandwidth(self):
		"""bandwidth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def center(self):
		"""center commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def name(self):
		"""name commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def rfbWidth(self):
		"""rfbWidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfbWidth'):
			from .RfbWidth import RfbWidthCls
			self._rfbWidth = RfbWidthCls(self._core, self._cmd_group)
		return self._rfbWidth

	@property
	def technology(self):
		"""technology commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_technology'):
			from .Technology import TechnologyCls
			self._technology = TechnologyCls(self._core, self._cmd_group)
		return self._technology

	@property
	def txChannel(self):
		"""txChannel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_txChannel'):
			from .TxChannel import TxChannelCls
			self._txChannel = TxChannelCls(self._core, self._cmd_group)
		return self._txChannel

	def clone(self) -> 'SblockCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SblockCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SignalCls:
	"""Signal commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("signal", core, parent)

	def set(self, state: enums.State) -> None:
		"""SCPI: [SENSe]:MIXer:SIGNal \n
		Snippet: driver.applications.k91Wlan.sense.mixer.signal.set(state = enums.State.ALL) \n
		This command specifies whether automatic signal detection is active or not. Note that automatic signal identification is
		only available for measurements that perform frequency sweeps (not in vector signal analysis or the I/Q Analyzer, for
		instance) . \n
			:param state: OFF | ON | AUTO | ALL OFF | ON | AUTO | ALL OFF No automatic signal detection is active. ON Automatic signal detection (Signal ID) is active. AUTO Automatic signal detection (Auto ID) is active. ALL Both automatic signal detection functions (Signal ID+Auto ID) are active.
		"""
		param = Conversions.enum_scalar_to_str(state, enums.State)
		self._core.io.write(f'SENSe:MIXer:SIGNal {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.State:
		"""SCPI: [SENSe]:MIXer:SIGNal \n
		Snippet: value: enums.State = driver.applications.k91Wlan.sense.mixer.signal.get() \n
		This command specifies whether automatic signal detection is active or not. Note that automatic signal identification is
		only available for measurements that perform frequency sweeps (not in vector signal analysis or the I/Q Analyzer, for
		instance) . \n
			:return: state: OFF | ON | AUTO | ALL OFF | ON | AUTO | ALL OFF No automatic signal detection is active. ON Automatic signal detection (Signal ID) is active. AUTO Automatic signal detection (Auto ID) is active. ALL Both automatic signal detection functions (Signal ID+Auto ID) are active."""
		response = self._core.io.query_str(f'SENSe:MIXer:SIGNal?')
		return Conversions.str_to_scalar_enum(response, enums.State)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BeginCls:
	"""Begin commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("begin", core, parent)

	def set(self, time: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:CHRDetection:FDEViation:OFFSet:BEGin \n
		Snippet: driver.applications.k60Transient.calculate.chrDetection.fdeviation.offset.begin.set(time = 1.0, window = repcap.Window.Default) \n
		Defines the beginning of the measurement range for frequency deviation results as an offset in seconds from the chirp
		start. This command is only available if the reference is EDGE (see method RsFsw.Applications.K60_Transient.Calculate.
		ChrDetection.Fdeviation.Reference.set) . For details on the measurement range parameters see 'Measurement range'. \n
			:param time: Unit: S
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(time)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:CHRDetection:FDEViation:OFFSet:BEGin {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:CHRDetection:FDEViation:OFFSet:BEGin \n
		Snippet: value: float = driver.applications.k60Transient.calculate.chrDetection.fdeviation.offset.begin.get(window = repcap.Window.Default) \n
		Defines the beginning of the measurement range for frequency deviation results as an offset in seconds from the chirp
		start. This command is only available if the reference is EDGE (see method RsFsw.Applications.K60_Transient.Calculate.
		ChrDetection.Fdeviation.Reference.set) . For details on the measurement range parameters see 'Measurement range'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: time: Unit: S"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:CHRDetection:FDEViation:OFFSet:BEGin?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FetchCls:
	"""Fetch commands group definition. 96 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fetch", core, parent)

	@property
	def burst(self):
		"""burst commands group. 29 Sub-classes, 0 commands."""
		if not hasattr(self, '_burst'):
			from .Burst import BurstCls
			self._burst = BurstCls(self._core, self._cmd_group)
		return self._burst

	@property
	def sfield(self):
		"""sfield commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sfield'):
			from .Sfield import SfieldCls
			self._sfield = SfieldCls(self._core, self._cmd_group)
		return self._sfield

	@property
	def symbol(self):
		"""symbol commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_symbol'):
			from .Symbol import SymbolCls
			self._symbol = SymbolCls(self._core, self._cmd_group)
		return self._symbol

	@property
	def scDetailed(self):
		"""scDetailed commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_scDetailed'):
			from .ScDetailed import ScDetailedCls
			self._scDetailed = ScDetailedCls(self._core, self._cmd_group)
		return self._scDetailed

	@property
	def uteSummary(self):
		"""uteSummary commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_uteSummary'):
			from .UteSummary import UteSummaryCls
			self._uteSummary = UteSummaryCls(self._core, self._cmd_group)
		return self._uteSummary

	@property
	def sfSummary(self):
		"""sfSummary commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sfSummary'):
			from .SfSummary import SfSummaryCls
			self._sfSummary = SfSummaryCls(self._core, self._cmd_group)
		return self._sfSummary

	def clone(self) -> 'FetchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FetchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	def set(self, sample_rate: float) -> None:
		"""SCPI: [SENSe]:SRATe \n
		Snippet: driver.applications.k149Uwb.sense.symbolRate.set(sample_rate = 1.0) \n
		Returns the sample rate set up for current measurement settings. \n
			:param sample_rate: numeric value
		"""
		param = Conversions.decimal_value_to_str(sample_rate)
		self._core.io.write(f'SENSe:SRATe {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SRATe \n
		Snippet: value: float = driver.applications.k149Uwb.sense.symbolRate.get() \n
		Returns the sample rate set up for current measurement settings. \n
			:return: sample_rate: numeric value"""
		response = self._core.io.query_str(f'SENSe:SRATe?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	def set(self, phase: enums.LisnPhase, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:LISN:PHASe \n
		Snippet: driver.inputPy.lisn.phase.set(phase = enums.LisnPhase.L1, inputIx = repcap.InputIx.Default) \n
		This command selects one LISN phase to be measured. \n
			:param phase: L1 L2 Available for networks with four phases (R&S ESH2Z5, R&S ENV4200 and R&S ENV432) L3 Available for networks with four phases (R&S ESH2Z5, R&S ENV4200 and R&S ENV432) N
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(phase, enums.LisnPhase)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:LISN:PHASe {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.LisnPhase:
		"""SCPI: INPut<ip>:LISN:PHASe \n
		Snippet: value: enums.LisnPhase = driver.inputPy.lisn.phase.get(inputIx = repcap.InputIx.Default) \n
		This command selects one LISN phase to be measured. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: phase: L1 L2 Available for networks with four phases (R&S ESH2Z5, R&S ENV4200 and R&S ENV432) L3 Available for networks with four phases (R&S ESH2Z5, R&S ENV4200 and R&S ENV432) N"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:LISN:PHASe?')
		return Conversions.str_to_scalar_enum(response, enums.LisnPhase)
